@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 from django.views.generic.detail import DetailView
 from django.contrib.sites.models import get_current_site
+from django.db.models import Q
 from django.utils import timezone
 
 from .models import FlatPage
@@ -13,23 +14,26 @@ class PageDetail(DetailView):
     context_object_name = "context"
     type = 'flatpages'
 
-    @property
-    def template_name(self):
-        domain_folder = self.type
+    def get_template_names(self):
+        _template_names = super(PageDetail, self).get_template_names()
+
+        template_names = []
+
+        base_path = '{}/{}.html'.format(self.type, self.page.get().slug)
+
         if self.site.id > 1:
-            domain_folder = "{0}/{1}".format(self.site, self.type)
+            template_names.append('{}/{}'.format(self.site, base_path))
 
-        _template = '{0}/{1}.html'.format(
-            domain_folder, self.page.get().slug)
-        return _template
+        template_names.append(base_path)
 
-    @property
-    def queryset(self):
+        return template_names + _template_names
+
+    def get_queryset(self):
         self.site = get_current_site(self.request)
         self.slug = self.kwargs.get('slug')
 
         self.page = self.model.objects.filter(
-            site=self.site,
+            Q(global_page=True) | Q(site=self.site),
             slug=self.slug,
             date_available__lte=timezone.now(),
             published=True)
